# Security

This package is part of the [Agent Governance Toolkit](https://github.com/microsoft/agent-governance-toolkit).

## Reporting Vulnerabilities

**Please do not report security vulnerabilities through public GitHub issues.**

For security reporting, please follow the guidance at the root repository:
https://github.com/microsoft/agent-governance-toolkit/blob/main/SECURITY.md

Or review Microsoft's security reporting guidance at:
https://aka.ms/SECURITY.md

## Security Advisories

See the [root SECURITY.md](https://github.com/microsoft/agent-governance-toolkit/blob/main/SECURITY.md#security-advisories) for all published advisories.
